@@ -1,9 +1,13 @@
 import matplotlib.pyplot as plt
 import numpy as np
+from mpl_toolkits.axisartist import ParasiteAxes
+from mpl_toolkits.axisartist.parasite_axes import HostAxes
+
 from .imu import push_imu
 from .utils import lowpass_butter
 from scipy.integrate import cumtrapz
 
+
 def plot_pushes(data, pushes, var="torque", start=True, stop=True, peak=True, ax=None):
     """
     Plot pushes from measurement wheel or ergometer data.
@@ -1070,3 +1074,69 @@ def overview_spider_plot(time, vel, rot_vel, dist, name='', mirror=False):
     ax4.legend(loc='upper left', prop={'size': 8})
 
     return ax1, ax2, ax3, ax4
+
+
+def plot_power_speed_dist(data, title=""):
+    """
+    Plot power, speed and distance versus time. Left (solid line) and right (dotted line) separately.
+
+    Parameters
+    ----------
+    data: dict
+        wheelchair ergometer data dictionary with dataframes
+    title: str
+        a title for the plot
+
+    Returns
+    -------
+    fig: matplotlib.figure.Figure
+    axes: tuple
+        the three axes objects
+
+    """
+    plt.style.use("seaborn-ticks")
+    fig = plt.figure()
+
+    # Generate three axes
+    host = HostAxes(fig, [0.15, 0.1, 0.65, 0.8])
+    par1 = ParasiteAxes(host, sharex=host)
+    par2 = ParasiteAxes(host, sharex=host)
+    host.parasites.append(par1)
+    host.parasites.append(par2)
+
+    # Edit axis visibility
+    host.axis["right"].set_visible(False)
+    par1.axis["right"].set_visible(True)
+    par1.axis["right"].major_ticklabels.set_visible(True)
+    par1.axis["right"].label.set_visible(True)
+
+    # Define third ax
+    new_axisline = par2.get_grid_helper().new_fixed_axis
+    par2.axis["right2"] = new_axisline(loc="right", axes=par2, offset=(60, 0))
+
+    fig.add_axes(host)
+
+    host.plot(data["left"]["time"], data["left"]["power"], "C0", label="Power left")
+    host.plot(data["right"]["time"], data["right"]["power"], "C0", linestyle="dotted", label="Power right")
+    par1.plot(data["left"]["time"], data["left"]["speed"], "C1", label="Speed left")
+    par1.plot(data["right"]["time"], data["right"]["speed"], "C1", linestyle="dotted", label="Speed right")
+    par2.plot(data["left"]["time"], data["left"]["dist"], "C2", label="Distance left")
+    par2.plot(data["right"]["time"], data["right"]["dist"], "C2", linestyle="dotted", label="Distance right")
+
+    host.autoscale(tight=True, axis="x")
+    host.set_ylim(0., max(max(data["left"]["power"]), max(data["right"]["power"])) * 1.5)
+    par1.set_ylim(0., max(max(data["left"]["speed"]), max(data["right"]["speed"])) * 1.1)
+    par2.set_ylim(0., max(max(data["left"]["dist"]), max(data["right"]["dist"])) * 1.1)
+
+    host.set_title(title)
+    host.set_xlabel("Time [s]")
+    host.set_ylabel("Power [W]")
+    par1.set_ylabel("Speed [m/s]")
+    par2.set_ylabel("Distance [m]")
+
+    host.legend(loc="upper left", frameon=True)  # make the legend
+    host.axis["left"].label.set_color("C0")
+    par1.axis["right"].label.set_color("C1")
+    par2.axis["right2"].label.set_color("C2")
+
+    return fig, (host, par1, par2)
